/*
  Copyright 2020 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.auth.network

import com.kakao.sdk.auth.AccessTokenRepo
import com.kakao.sdk.common.Constants
import okhttp3.Interceptor
import okhttp3.Request
import okhttp3.Response

/**
 * @suppress
 *
 * API 요청에 AccessToken을 추가하는 인터셉터
 *
 * TODO: Authenticator로 구현해보자
 */
class AccessTokenInterceptor(
    private val tokenRepo: AccessTokenRepo = AccessTokenRepo.instance
) : Interceptor {
    override fun intercept(chain: Interceptor.Chain): Response {
        val request =
            tokenRepo.getToken()?.accessToken?.let {
                requestWithAuthorization(chain.request(), it)
            } ?: chain.request()

        return chain.proceed(request)
    }

    companion object {
        fun requestWithAuthorization(request: Request, accessToken: String): Request =
            request.newBuilder()
                .removeHeader(Constants.AUTHORIZATION)
                .addHeader(Constants.AUTHORIZATION, "${Constants.BEARER} $accessToken")
                .build()
    }
}
